@@ -8,7 +8,7 @@ from sqlalchemy_filters import apply_filters, apply_sort, apply_pagination
 from .table import DataTable
 
 
-class FilterSpec(TypedDict):
+class FilterSpec(TypedDict, total=False):
     model: Optional[str]
     field: str
     op: str
@@ -174,9 +174,11 @@ class FiltrationData(BaseModel):
         if isinstance(operator, str):
             operator = FiltrationOperator(operator)
 
-        self.to_filter += {
+        spec: FilterSpec = {
             "field": field,
             "value": value,
-            "op": operator,
+            "op": operator.value,
         }
+
+        self.to_filter += spec
         return self
